==> touhoulittlemaid-fabric-1.20.1-0.1.7.3-forge1.3.8-sources.jar: com/github/tartaricacid/touhoulittlemaid/item/ItemEntityPlaceholder.java <==
package com.github.tartaricacid.touhoulittlemaid.item;

import cn.sh1rocu.touhoulittlemaid.api.extension.IItemRenderer;
import cn.sh1rocu.touhoulittlemaid.mixin.accessor.RecipeManagerAccessor;
import com.github.tartaricacid.touhoulittlemaid.client.renderer.tileentity.TileEntityEntityPlaceholderRenderer;
import com.github.tartaricacid.touhoulittlemaid.crafting.AltarRecipe;
import com.github.tartaricacid.touhoulittlemaid.init.InitItems;
import com.github.tartaricacid.touhoulittlemaid.init.InitRecipes;
import com.github.tartaricacid.touhoulittlemaid.inventory.AltarRecipeInventory;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_1269;
import net.minecraft.class_1761;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1838;
import net.minecraft.class_1860;
import net.minecraft.class_1937;
import net.minecraft.class_2350;
import net.minecraft.class_2487;
import net.minecraft.class_2520;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_3218;
import net.minecraft.class_638;
import net.minecraft.class_756;
import javax.annotation.Nullable;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.Locale;

public class ItemEntityPlaceholder extends class_1792 implements IItemRenderer {
    private static final String RECIPES_ID_TAG = "RecipeId";

    @Environment(EnvType.CLIENT)
    @Override
    public class_756 getCustomRenderer() {
        class_310 minecraft = class_310.method_1551();
        return new TileEntityEntityPlaceholderRenderer(minecraft.method_31975(), minecraft.method_31974());
    }

    public ItemEntityPlaceholder() {
        super(new class_1793().method_7889(1));
    }

    public static class_1799 setRecipeId(class_1799 stack, class_2960 id) {
        stack.method_7948().method_10582(RECIPES_ID_TAG, id.toString());
        return stack;
    }


    @SuppressWarnings("all")
    @Nullable
    public static class_2960 getRecipeId(class_1799 stack) {
        if (stack.method_7985()) {
            class_2487 tag = stack.method_7969();
            if (tag.method_10573(RECIPES_ID_TAG, class_2520.field_33258)) {
                return new class_2960(tag.method_10558(RECIPES_ID_TAG));
            }
        }
        return null;
    }

    @Environment(EnvType.CLIENT)
    public static void fillItemCategory(class_1761.class_7704 items) {
        class_638 world = class_310.method_1551().field_1687;
        if (world == null) {
            return;
        }
        world.method_8433().method_30027(InitRecipes.ALTAR_CRAFTING).forEach(recipe -> {
            if (!recipe.isItemCraft()) {
                items.method_45420(setRecipeId(new class_1799(InitItems.ENTITY_PLACEHOLDER), recipe.method_8114()));
            }
        });
    }

    @Override
    public class_1269 method_7884(class_1838 context) {
        if (context.method_8038() == class_2350.field_11036) {
            class_2960 id = getRecipeId(context.method_8041());
            class_1937 world = context.method_8045();
            if (id != null && world instanceof class_3218) {
                class_1860<AltarRecipeInventory> recipe = ((RecipeManagerAccessor) context.method_8045().method_8433()).tlm$byType(InitRecipes.ALTAR_CRAFTING).get(id);
                if (recipe instanceof AltarRecipe) {
                    AltarRecipe altarRecipe = (AltarRecipe) recipe;
                    altarRecipe.spawnOutputEntity((class_3218) world, context.method_8037().method_10084(), null);
                    context.method_8041().method_7934(1);
                }
            }
        }
        return super.method_7884(context);
    }

    @Override
    @Environment(EnvType.CLIENT)
    public class_2561 method_7864(class_1799 stack) {
        class_2960 recipeId = getRecipeId(stack);
        if (recipeId != null) {
            Path path = Paths.get(recipeId.method_12832().toLowerCase(Locale.US));
            String namespace = recipeId.method_12836().toLowerCase(Locale.US);
            String langKey = String.format("jei.%s.altar_craft.%s.result", namespace, path.getFileName());
            return class_2561.method_43471(langKey);
        }
        return class_2561.method_43471("item.touhou_little_maid.entity_placeholder");
    }
}

==> touhoulittlemaid-fabric-1.20.1-0.4.2-forge1.4.5-sources.jar: com/github/tartaricacid/touhoulittlemaid/item/ItemEntityPlaceholder.java <==
package com.github.tartaricacid.touhoulittlemaid.item;

import cn.sh1rocu.touhoulittlemaid.api.extension.IItemRenderer;
import cn.sh1rocu.touhoulittlemaid.mixin.accessor.RecipeManagerAccessor;
import com.github.tartaricacid.touhoulittlemaid.client.renderer.tileentity.TileEntityEntityPlaceholderRenderer;
import com.github.tartaricacid.touhoulittlemaid.crafting.AltarRecipe;
import com.github.tartaricacid.touhoulittlemaid.init.InitItems;
import com.github.tartaricacid.touhoulittlemaid.init.InitRecipes;
import com.github.tartaricacid.touhoulittlemaid.inventory.AltarRecipeInventory;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_1269;
import net.minecraft.class_1761;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1838;
import net.minecraft.class_1860;
import net.minecraft.class_1937;
import net.minecraft.class_2350;
import net.minecraft.class_2487;
import net.minecraft.class_2520;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_3218;
import net.minecraft.class_638;
import net.minecraft.class_756;
import javax.annotation.Nullable;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.Locale;

public class ItemEntityPlaceholder extends class_1792 implements IItemRenderer {
    private static final String RECIPES_ID_TAG = "RecipeId";

    @Environment(EnvType.CLIENT)
    @Override
    public class_756 getCustomRenderer() {
        return TileEntityEntityPlaceholderRenderer.INSTANCE.get();
    }

    public ItemEntityPlaceholder() {
        super(new class_1793().method_7889(1));
    }

    public static class_1799 setRecipeId(class_1799 stack, class_2960 id) {
        stack.method_7948().method_10582(RECIPES_ID_TAG, id.toString());
        return stack;
    }


    @SuppressWarnings("all")
    @Nullable
    public static class_2960 getRecipeId(class_1799 stack) {
        if (stack.method_7985()) {
            class_2487 tag = stack.method_7969();
            if (tag.method_10573(RECIPES_ID_TAG, class_2520.field_33258)) {
                return new class_2960(tag.method_10558(RECIPES_ID_TAG));
            }
        }
        return null;
    }

    @Environment(EnvType.CLIENT)
    public static void fillItemCategory(class_1761.class_7704 items) {
        class_638 world = class_310.method_1551().field_1687;
        if (world == null) {
            return;
        }
        world.method_8433().method_30027(InitRecipes.ALTAR_CRAFTING).forEach(recipe -> {
            if (!recipe.isItemCraft()) {
                items.method_45420(setRecipeId(new class_1799(InitItems.ENTITY_PLACEHOLDER), recipe.method_8114()));
            }
        });
    }

    @Override
    public class_1269 method_7884(class_1838 context) {
        if (context.method_8038() == class_2350.field_11036) {
            class_2960 id = getRecipeId(context.method_8041());
            class_1937 world = context.method_8045();
            if (id != null && world instanceof class_3218) {
                class_1860<AltarRecipeInventory> recipe = ((RecipeManagerAccessor) context.method_8045().method_8433()).tlm$byType(InitRecipes.ALTAR_CRAFTING).get(id);
                if (recipe instanceof AltarRecipe altarRecipe) {
                    altarRecipe.spawnOutputEntity((class_3218) world, context.method_8037().method_10084(), null);
                    context.method_8041().method_7934(1);
                }
            }
        }
        return super.method_7884(context);
    }

    @Override
    @Environment(EnvType.CLIENT)
    public class_2561 method_7864(class_1799 stack) {
        class_2960 recipeId = getRecipeId(stack);
        if (recipeId != null) {
            Path path = Paths.get(recipeId.method_12832().toLowerCase(Locale.US));
            String namespace = recipeId.method_12836().toLowerCase(Locale.US);
            String langKey = String.format("jei.%s.altar_craft.%s.result", namespace, path.getFileName());
            return class_2561.method_43471(langKey);
        }
        return class_2561.method_43471("item.touhou_little_maid.entity_placeholder");
    }
}
